@@ -1,13 +1,13 @@
 package Debug::Client;
 use strict;
 use warnings;
-use 5.006;
+use 5.008;
 
-our $VERSION = '0.13_03';
+our $VERSION = '0.13_04';
 
 use utf8;
 use IO::Socket;
-use Carp ();
+use Carp qw(carp croak cluck);
 
 =head1 NAME
 
@@ -17,7 +17,7 @@ Debug::Client - client side code for perl debugger
 
   use Debug::Client;
   my $debugger = Debug::Client->new(host => $host, port => $port);
-  $debugger->listen;
+  $debugger->listener;
 
 Where $host is the hostname to be used by the script under test (SUT)
 to acces the machine where Debug::Client runs. If they are on the same machine
@@ -33,7 +33,7 @@ then running
 
   perl -d script
 
-Once the script under test wa launched we can call the following:
+Once the script under test was launched we can call the following:
 
   my $out = $debugger->get;
 
@@ -99,7 +99,7 @@ Other planned methods:
     host => $host,
     port => $port,
   );
-  $debugger->listen;
+  $debugger->listener;
   my $out = $debugger->get;
   $out = $debugger->step_in;
   # ...
@@ -118,7 +118,7 @@ The constructor can get two parameters: host and port.
    
 Immediately after the object creation one needs to call
 
-  $debugger->listen;
+  $debugger->listener;
   
 TODO: Is there any reason to separate the two?
 
@@ -141,11 +141,33 @@ sub new {
 
 =head2 listen
 
-See C<new>
+Has bean deprecated in this version 0.13_04 and all future versions starting with v0.14
+
+Perl::Critic Error Subroutine name is a homonym for builtin function
+
+Use $debugger->listener instead
 
 =cut
 
 sub listen {
+	my ($self, @args) = @_;
+	$self->listener(@args);
+	return;
+}
+
+=head2 listener
+
+listener/hearken To listen attentively; give heed.
+
+See C<new>
+
+ $debugger->listener
+
+=cut
+#######
+# Method listener
+#######
+sub listener {
 	my ($self) = @_;
 
 	# Open the socket the debugger will connect to.
@@ -154,9 +176,11 @@ sub listen {
 		LocalPort => $self->{port},
 		Proto     => 'tcp',
 		Listen    => SOMAXCONN,
-		Reuse     => 1
+
+		# Reuse     => 1,	#(deprecated, prefer ReuseAddr)
+		ReuseAddr => 1,
 	);
-	$sock or die "Could not connect to '$self->{host}' '$self->{port}' no socket :$!";
+	$sock or carp "Could not connect to '$self->{host}' '$self->{port}' no socket :$!";
 	_logger("listening on '$self->{host}:$self->{port}'");
 	$self->{sock} = $sock;
 
@@ -173,6 +197,9 @@ Returns the content of the buffer since the last command
 
 =cut
 
+#######
+# Method buffer
+#######
 sub buffer {
 	my ($self) = @_;
 	return $self->{buffer};
@@ -184,32 +211,64 @@ sub buffer {
 
 =cut
 
-sub quit { $_[0]->_send('q') }
+#######
+# Method quit
+#######
+sub quit {
+	my $self = shift;
+	return $self->_send('q');
+}
 
 =head2 show_line
 
+.
+
+Return the internal debugger pointer to the line last executed, and print out that line.
+
  $debugger->show_line();
 
 =cut
-
-sub show_line { $_[0]->_send_get('.') }
-
+#######
+# Method show_line
+#######
+sub show_line {
+	my $self = shift;
+	return $self->_send_get('.');
+}
 
 =head2 step_in
 
+s [expr]
+
+Single step. 
+Executes until the beginning of another statement, descending into subroutine calls. 
+If an expression is supplied that includes function calls, it too will be single-stepped.
+
  $debugger->step_in();
 
-=cut
+Expresions not supported. 
 
-sub step_in { $_[0]->_send_get('s') }
+=cut
+#######
+# Method step_in
+#######
+sub step_in {
+	my $self = shift;
+	return $self->_send_get('s');
+}
 
 =head2 step_over
 
  $debugger->step_over();
 
 =cut
-
-sub step_over { $_[0]->_send_get('n') }
+#######
+# Method step_over
+#######
+sub step_over {
+	my $self = shift;
+	return $self->_send_get('n');
+}
 
 =head2 step_out
 
@@ -231,7 +290,7 @@ or when some of the elements of the returned array are themselves references
 sub step_out {
 	my ($self) = @_;
 
-	Carp::croak('Must call step_out in list context') if not wantarray;
+	carp('Must call step_out in list context') if not wantarray;
 
 	$self->_send('r');
 	my $buf = $self->_get;
@@ -317,7 +376,7 @@ List subroutine names [not] matching pattern.
 #######
 sub list_subroutine_names {
 	my ( $self, $pattern ) = @_;
-	
+
 	if ( defined $pattern ) {
 		$self->_send("S $pattern");
 	} else {
@@ -344,10 +403,11 @@ the script. (Like pressing c in the debugger).
 sub run {
 	my ( $self, $param ) = @_;
 	if ( not defined $param ) {
-		$self->_send_get('c');
+		return $self->_send_get('c');
 	} else {
-		$self->_send_get("c $param");
+		return $self->_send_get("c $param");
 	}
+
 }
 
 
@@ -478,7 +538,7 @@ sub list_break_watch_action {
 			);
 			push @breakpoints, \%bp;
 		} else {
-			die "No breakpoint found in '$buf'";
+			carp "No breakpoint found in '$buf'";
 		}
 	}
 
@@ -516,7 +576,7 @@ value of that reference?
 # or its user) should actually call   x $var
 sub get_value {
 	my ( $self, $var ) = @_;
-	die "no parameter given\n" if not defined $var;
+	carp "no parameter given\n" if not defined $var;
 
 	if ( $var =~ /^\$/ ) {
 		$self->_send("p $var");
@@ -530,7 +590,8 @@ sub get_value {
 		my $data_ref = _parse_dumper($buf);
 		return $data_ref;
 	}
-	die "Unknown parameter '$var'\n";
+	carp "Unknown parameter '$var'\n";
+	return;
 }
 
 =head2 get_y_zero
@@ -581,8 +642,6 @@ Make sure you don't put the type specifier (like $ ) there, just the symbol name
 sub get_v_vars {
 	my ( $self, $pattern ) = @_;
 
-	#TODO test for valid pattern ?
-	# die "no pattern given\n" if not defined $pattern;
 	if ( defined $pattern ) {
 		$self->_send("V $pattern");
 	} else {
@@ -607,7 +666,6 @@ X [vars] Same as V currentpackage [vars]
 sub get_x_vars {
 	my ( $self, $pattern ) = @_;
 
-	# die "no pattern given\n" if not defined $pattern;
 	if ( defined $pattern ) {
 		$self->_send("X $pattern");
 	} else {
@@ -655,16 +713,26 @@ sub get {
  $debugger->filename();
 
 =cut
-
-sub filename { return $_[0]->{filename} }
+#######
+# Method filename
+#######
+sub filename {
+	my $self = shift;
+	return $self->{filename};
+}
 
 =head2 row
 
  $debugger->row();
 
 =cut
-
-sub row { return $_[0]->{row} }
+#######
+# Method row
+#######
+sub row {
+	my $self = shift;
+	return $self->{row};
+}
 
 #########################################
 #### Internal Methods
@@ -681,7 +749,7 @@ sub _get {
 	while ( $buf !~ /DB<\d+>/ ) {
 		my $ret = $self->{new_sock}->sysread( $buf, 1024, length $buf );
 		if ( not defined $ret ) {
-			die $!; # TODO better error handling?
+			carp $!; # TODO better error handling?
 		}
 		_logger("---- ret '$ret'\n$buf\n---");
 		if ( not $ret ) {
@@ -699,6 +767,7 @@ sub _get {
 #######
 sub _logger {
 	print "LOG: $_[0]\n" if $ENV{DEBUG_LOGGER};
+	return;
 }
 
 #######
@@ -726,7 +795,7 @@ sub _process_line {
 	my ( $self, $buf ) = @_;
 
 	if ( not defined $buf or not ref $buf or ref $buf ne 'SCALAR' ) {
-		Carp::croak('_process_line should be called with a reference to a scalar');
+		carp('_process_line should be called with a reference to a scalar');
 	}
 
 	if ( $$buf =~ /Debugged program terminated/ ) {
@@ -739,7 +808,7 @@ sub _process_line {
 	# try to debug some test reports
 	# http://www.nntp.perl.org/group/perl.cpan.testers/2009/12/msg6542852.html
 	if ( not defined $line ) {
-		Carp::croak("Debug::Client: Line is undef. Buffer is '$$buf'");
+		carp("Debug::Client: Line is undef. Buffer is '$$buf'");
 	}
 	_logger("Line: '$line'");
 	my $cont;
@@ -784,7 +853,7 @@ sub _prompt {
 	my ( $self, $buf ) = @_;
 
 	if ( not defined $buf or not ref $buf or ref $buf ne 'SCALAR' ) {
-		Carp::croak('_prompt should be called with a reference to a scalar');
+		croak('_prompt should be called with a reference to a scalar');
 	}
 
 	my $prompt;
@@ -804,6 +873,8 @@ sub _send {
 
 	#print "Sending '$input'\n";
 	print { $self->{new_sock} } "$input\n";
+
+	return 1;
 }
 
 #######
